@@ -1,4 +1,4 @@
-# $Id: Simple.pm,v 1.11 2004/12/04 11:46:19 dave Exp $
+# $Id: Simple.pm,v 1.12 2005/03/01 14:31:50 dave Exp $
 
 =head1 NAME
 
@@ -26,12 +26,12 @@ require Exporter;
 @ISA = qw(Exporter);
 
 @EXPORT = qw(calendar);
-$VERSION = sprintf "%d.%02d", '$Revision: 1.11 $ ' =~ /(\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%02d", '$Revision: 1.12 $ ' =~ /(\d+)\.(\d+)/;
 
 use Time::Local;
 use Carp;
 
-eval "use DateTime";
+eval 'use DateTime';
 my $dt = ! $@;
 $dt = 0 if $ENV{CAL_SIMPLE_NO_DT};
 
@@ -177,6 +177,9 @@ L<perl>, L<localtime>, L<DateTime>
 
 #
 # $Log: Simple.pm,v $
+# Revision 1.12  2005/03/01 14:31:50  dave
+# Adding pod coverage tests
+#
 # Revision 1.11  2004/12/04 11:46:19  dave
 # Added 'see also' reference to DateTime
 #
